@@ -1,6 +1,6 @@
 #![cfg_attr(docsrs, feature(doc_cfg))]
 //#![warn(clippy::all)]
-//#![warn(missing_docs)]
+#![warn(missing_docs)]
 //!
 //! A 3D renderer which enables out-of-the-box build to both desktop and web with the same code.
 //! See the [README](https://crates.io/crates/three-d) for more information and
@@ -24,4 +24,5 @@ mod gui;
 #[doc(inline)]
 pub use gui::*;
 
+/// A result for this crate.
 pub type ThreeDResult<T> = std::result::Result<T, Box<dyn std::error::Error>>;
