@@ -2,17 +2,24 @@ use crate::core::*;
 use crate::renderer::*;
 use std::rc::Rc;
 
+///
+/// Render the object with colors that reflect its normals which primarily is used for debug purposes.
+/// A normal with an x value of -1 yields 0.0 in the red channel and an x value of 1 yields 1.0 in the red channel.
+/// The same mapping is applied from y value to green channel and z value to blue channel.
+///
 #[derive(Clone)]
 pub struct NormalMaterial {
     /// A scalar multiplier applied to each normal vector of the [Self::normal_texture].
     pub normal_scale: f32,
     /// A tangent space normal map, also known as bump map.
-    pub normal_texture: Option<Rc<Texture2D<u8>>>,
+    pub normal_texture: Option<Rc<Texture2D>>,
+    /// Render states.
     pub render_states: RenderStates,
 }
 
 impl NormalMaterial {
-    pub fn new(context: &Context, cpu_material: &CPUMaterial) -> ThreeDResult<Self> {
+    /// Constructs a new normal material from a [CpuMaterial] where only relevant information is used.
+    pub fn new(context: &Context, cpu_material: &CpuMaterial) -> ThreeDResult<Self> {
         let normal_texture = if let Some(ref cpu_texture) = cpu_material.normal_texture {
             Some(Rc::new(Texture2D::new(&context, cpu_texture)?))
         } else {
@@ -25,17 +32,22 @@ impl NormalMaterial {
         })
     }
 
+    /// Creates a normal material from a [PhysicalMaterial].
     pub fn from_physical_material(physical_material: &PhysicalMaterial) -> Self {
         Self {
             normal_scale: physical_material.normal_scale,
             normal_texture: physical_material.normal_texture.clone(),
-            render_states: physical_material.opaque_render_states,
+            render_states: RenderStates {
+                write_mask: WriteMask::default(),
+                blend: Blend::Disabled,
+                ..physical_material.render_states
+            },
         }
     }
 }
 
 impl Material for NormalMaterial {
-    fn fragment_shader_source(&self, _use_vertex_colors: bool, _lights: &Lights) -> String {
+    fn fragment_shader_source(&self, _use_vertex_colors: bool, _lights: &[&dyn Light]) -> String {
         let mut shader = String::new();
         if self.normal_texture.is_some() {
             shader.push_str("#define USE_TEXTURE\nin vec2 uvs;\nin vec3 tang;\nin vec3 bitang;\n");
@@ -47,11 +59,11 @@ impl Material for NormalMaterial {
         &self,
         program: &Program,
         _camera: &Camera,
-        _lights: &Lights,
+        _lights: &[&dyn Light],
     ) -> ThreeDResult<()> {
         if let Some(ref tex) = self.normal_texture {
-            program.use_uniform_float("normalScale", &self.normal_scale)?;
-            program.use_texture("normalTexture", &**tex)?;
+            program.use_uniform("normalScale", &self.normal_scale)?;
+            program.use_texture("normalTexture", tex)?;
         }
         Ok(())
     }
