@@ -1,20 +1,25 @@
 use crate::core::*;
 use crate::renderer::*;
 
-#[derive(Clone, Default)]
+///
+/// Render the object with colors that reflect its position which primarily is used for debug purposes.
+/// The x coordinate maps to the red channel, y to green and z to blue.
+///
+#[derive(Default, Clone)]
 pub struct PositionMaterial {
+    /// Render states.
     pub render_states: RenderStates,
 }
 
 impl Material for PositionMaterial {
-    fn fragment_shader_source(&self, _use_vertex_colors: bool, _lights: &Lights) -> String {
+    fn fragment_shader_source(&self, _use_vertex_colors: bool, _lights: &[&dyn Light]) -> String {
         include_str!("shaders/position_material.frag").to_string()
     }
     fn use_uniforms(
         &self,
         _program: &Program,
         _camera: &Camera,
-        _lights: &Lights,
+        _lights: &[&dyn Light],
     ) -> ThreeDResult<()> {
         Ok(())
     }
